==> mingw-w64-clang-aarch64-glfw-3.3.9-1-any.pkg.tar.zst: clangarm64/share/doc/glfw/html/search/all_1a.js <==
var searchData=
[
  ['wait_20for_20events_0',['No window required to wait for events',['../news.html#wait_events_33',1,'']]],
  ['wait_20for_20events_20with_20timeout_1',['Wait for events with timeout',['../news.html#news_32_waittimeout',1,'']]],
  ['wake_20up_2',['Main thread wake-up',['../news.html#news_31_emptyevent',1,'']]],
  ['wayland_20libdecor_20decorations_3',['Wayland libdecor decorations',['../news.html#wayland_libdecor_33',1,'']]],
  ['wayland_20on_20unix_20like_20systems_4',['Dependencies for Wayland on Unix-like systems',['../compile_guide.html#compile_deps_wayland',1,'']]],
  ['wayland_20protocols_20and_20ipc_20standards_5',['Wayland protocols and IPC standards',['../compat_guide.html#compat_wayland',1,'']]],
  ['wayland_20specific_20cmake_20options_6',['Wayland specific CMake options',['../compile_guide.html#compile_options_wayland',1,'']]],
  ['wayland_20specific_20init_20hints_7',['Wayland specific init hints',['../intro_guide.html#init_hints_wayland',1,'']]],
  ['wayland_20support_8',['(Experimental) Wayland support',['../news.html#news_31_wayland',1,'']]],
  ['wayland_20systems_9',['Frambuffer may lack alpha channel on older Wayland systems',['../news.html#wayland_alpha_34',1,'']]],
  ['wgl_20extensions_10',['WGL extensions',['../compat_guide.html#compat_wgl',1,'']]],
  ['wheel_20position_20replaced_20by_20scroll_20offsets_11',['Wheel position replaced by scroll offsets',['../moving_guide.html#moving_wheel',1,'']]],
  ['wide_20hotkeys_12',['Capture of system-wide hotkeys',['../moving_guide.html#moving_syskeys',1,'']]],
  ['width_13',['width',['../struct_g_l_f_wvidmode.html#a698dcb200562051a7249cb6ae154c71d',1,'GLFWvidmode::width'],['../struct_g_l_f_wimage.html#af6a71cc999fe6d3aea31dd7e9687d835',1,'GLFWimage::width']]],
  ['win32_20mbcs_20support_14',['Win32 MBCS support',['../moving_guide.html#moving_mbcs',1,'']]],
  ['window_15',['Creating the window',['../vulkan_guide.html#vulkan_window',1,'']]],
  ['window_20and_20context_16',['Creating a window and context',['../quick_guide.html#quick_create_window',1,'']]],
  ['window_20and_20framebuffer_20sizes_17',['Separation of window and framebuffer sizes',['../moving_guide.html#moving_hidpi',1,'']]],
  ['window_20attention_20request_18',['Window attention request',['../window_guide.html#window_attention',1,'']]],
  ['window_20attribute_19',['Mouse cursor hover window attribute',['../news.html#cursor_hover_33',1,'']]],
  ['window_20attributes_20',['window attributes',['../news.html#setwindowattrib_33',1,'Support for updating window attributes'],['../window_guide.html#window_attribs',1,'Window attributes']]],
  ['window_20attributes_20and_20cursor_20position_21',['Direct access for window attributes and cursor position',['../news.html#news_31_direct',1,'']]],
  ['window_20close_20flag_22',['Checking the window close flag',['../quick_guide.html#quick_window_close',1,'']]],
  ['window_20closing_20and_20close_20flag_23',['Window closing and close flag',['../window_guide.html#window_close',1,'']]],
  ['window_20closing_20changes_24',['Window closing changes',['../moving_guide.html#moving_window_close',1,'']]],
  ['window_20content_20scale_25',['Window content scale',['../window_guide.html#window_scale',1,'']]],
  ['window_20creation_26',['Window creation',['../window_guide.html#window_creation',1,'']]],
  ['window_20creation_20hints_27',['Window creation hints',['../window_guide.html#window_hints',1,'']]],
  ['window_20damage_20and_20refresh_28',['Window damage and refresh',['../window_guide.html#window_refresh',1,'']]],
  ['window_20destruction_29',['Window destruction',['../window_guide.html#window_destruction',1,'']]],
  ['window_20event_20processing_30',['Window event processing',['../window_guide.html#window_events',1,'']]],
  ['window_20focus_20callback_31',['Window focus callback',['../news.html#news_30_focusfun',1,'']]],
  ['window_20frame_20size_20query_32',['Window frame size query',['../news.html#news_31_framesize',1,'']]],
  ['window_20guide_33',['Window guide',['../window_guide.html',1,'']]],
  ['window_20handle_20parameters_34',['Window handle parameters',['../moving_guide.html#moving_window_handles',1,'']]],
  ['window_20hint_35',['Cursor centering window hint',['../news.html#center_cursor_33',1,'']]],
  ['window_20hint_20and_20attribute_20for_20input_20focus_20on_20show_36',['Window hint and attribute for input focus on show',['../news.html#focusonshow_33',1,'']]],
  ['window_20hints_37',['window hints',['../window_guide.html#window_hints_osx',1,'macOS specific window hints'],['../moving_guide.html#moving_hints',1,'Persistent window hints'],['../window_guide.html#window_hints_x11',1,'X11 specific window hints']]],
  ['window_20icon_38',['Window icon',['../window_guide.html#window_icon',1,'']]],
  ['window_20icon_20support_39',['Window icon support',['../news.html#news_32_icon',1,'']]],
  ['window_20iconification_40',['Window iconification',['../window_guide.html#window_iconify',1,'']]],
  ['window_20iconification_20callback_41',['Window iconification callback',['../news.html#news_30_iconifyfun',1,'']]],
  ['window_20input_20focus_42',['Window input focus',['../window_guide.html#window_focus',1,'']]],
  ['window_20input_20focus_20control_43',['Window input focus control',['../news.html#news_32_focus',1,'']]],
  ['window_20maximization_44',['Window maximization',['../window_guide.html#window_maximize',1,'']]],
  ['window_20maximization_20callback_45',['Window maximization callback',['../news.html#maximize_33',1,'']]],
  ['window_20maxmimization_20support_46',['Window maxmimization support',['../news.html#news_32_maximize',1,'']]],
  ['window_20mode_20switching_47',['Window mode switching',['../news.html#news_32_setwindowmonitor',1,'']]],
  ['window_20monitor_48',['Window monitor',['../window_guide.html#window_monitor',1,'']]],
  ['window_20objects_49',['Window objects',['../window_guide.html#window_object',1,'']]],
  ['window_20parameter_20to_20clipboard_20functions_50',['Window parameter to clipboard functions',['../news.html#clipboard_window_33',1,'']]],
  ['window_20position_51',['Window position',['../window_guide.html#window_pos',1,'']]],
  ['window_20position_20callback_52',['Window position callback',['../news.html#news_30_wndposfun',1,'']]],
  ['window_20position_20query_53',['Window position query',['../news.html#news_30_wndpos',1,'']]],
  ['window_20properties_20and_20events_54',['Window properties and events',['../window_guide.html#window_properties',1,'']]],
  ['window_20reference_55',['Window reference',['../group__window.html',1,'']]],
  ['window_20related_20attributes_56',['Window related attributes',['../window_guide.html#window_attribs_wnd',1,'']]],
  ['window_20related_20hints_57',['Window related hints',['../window_guide.html#window_hints_wnd',1,'']]],
  ['window_20required_20to_20wait_20for_20events_58',['No window required to wait for events',['../news.html#wait_events_33',1,'']]],
  ['window_20size_59',['Window size',['../window_guide.html#window_size',1,'']]],
  ['window_20size_20limit_20support_60',['Window size limit support',['../news.html#news_32_sizelimits',1,'']]],
  ['window_20size_20limits_61',['Window size limits',['../window_guide.html#window_sizelimits',1,'']]],
  ['window_20support_62',['Multi-window support',['../news.html#news_30_multiwnd',1,'']]],
  ['window_20surface_63',['Creating a Vulkan window surface',['../vulkan_guide.html#vulkan_surface',1,'']]],
  ['window_20title_64',['window title',['../news.html#news_30_wndtitle',1,'Initial window title'],['../window_guide.html#window_title',1,'Window title']]],
  ['window_20transparency_65',['Window transparency',['../window_guide.html#window_transparency',1,'']]],
  ['window_20user_20pointer_66',['Per-window user pointer',['../news.html#news_30_wndptr',1,'']]],
  ['window_20visibility_67',['Window visibility',['../window_guide.html#window_hide',1,'']]],
  ['window_2edox_68',['window.dox',['../window_8dox.html',1,'']]],
  ['windowed_20full_20screen_20windows_69',['&quot;Windowed full screen&quot; windows',['../window_guide.html#window_windowed_full_screen',1,'']]],
  ['windows_70',['windows',['../window_guide.html#window_windowed_full_screen',1,'&quot;Windowed full screen&quot; windows'],['../news.html#news_32_noapi',1,'Context-less windows'],['../news.html#news_31_floating',1,'Floating windows'],['../window_guide.html#window_full_screen',1,'Full screen windows'],['../news.html#news_30_hidden',1,'Hidden windows'],['../news.html#news_31_focused',1,'Initially unfocused windows'],['../news.html#news_30_undecorated',1,'Undecorated windows'],['../build_guide.html#build_link_win32',1,'With MinGW or Visual C++ on Windows']]],
  ['windows_20and_20framebuffers_71',['Transparent windows and framebuffers',['../news.html#transparency_33',1,'']]],
  ['windows_20older_20than_20xp_72',['Support for versions of Windows older than XP',['../moving_guide.html#moving_windows',1,'']]],
  ['windows_20specific_20cmake_20options_73',['Windows specific CMake options',['../compile_guide.html#compile_options_win32',1,'']]],
  ['windows_20without_20contexts_74',['Windows without contexts',['../context_guide.html#context_less',1,'']]],
  ['windows_20xinput_20deadzone_20removed_75',['Windows XInput deadzone removed',['../news.html#xinput_deadzone_33',1,'']]],
  ['with_20a_20loader_20library_76',['Loading extension with a loader library',['../context_guide.html#context_glext_auto',1,'']]],
  ['with_20cmake_77',['Generating build files with CMake',['../compile_guide.html#compile_generate',1,'']]],
  ['with_20cmake_20and_20glfw_20source_78',['With CMake and GLFW source',['../build_guide.html#build_link_cmake_source',1,'']]],
  ['with_20cmake_20and_20installed_20glfw_20binaries_79',['With CMake and installed GLFW binaries',['../build_guide.html#build_link_cmake_package',1,'']]],
  ['with_20cmake_20and_20mingw_80',['Cross-compilation with CMake and MinGW',['../compile_guide.html#compile_mingw_cross',1,'']]],
  ['with_20command_20line_20on_20macos_81',['With command-line on macOS',['../build_guide.html#build_link_osx',1,'']]],
  ['with_20makefiles_20and_20pkg_20config_20on_20unix_82',['With makefiles and pkg-config on Unix',['../build_guide.html#build_link_pkgconfig',1,'']]],
  ['with_20mingw_20or_20visual_20c_20on_20windows_83',['With MinGW or Visual C++ on Windows',['../build_guide.html#build_link_win32',1,'']]],
  ['with_20modifiers_20callback_84',['with modifiers callback',['../news.html#news_31_charmods',1,'Character with modifiers callback'],['../news.html#charmods_callback_33',1,'Character with modifiers callback']]],
  ['with_20opengl_85',['Rendering with OpenGL',['../quick_guide.html#quick_render',1,'']]],
  ['with_20the_20cmake_20command_20line_20tool_86',['Generating files with the CMake command-line tool',['../compile_guide.html#compile_generate_cli',1,'']]],
  ['with_20the_20cmake_20gui_87',['Generating files with the CMake GUI',['../compile_guide.html#compile_generate_gui',1,'']]],
  ['with_20the_20right_20libraries_88',['Link with the right libraries',['../build_guide.html#build_link',1,'']]],
  ['with_20timeout_89',['Wait for events with timeout',['../news.html#news_32_waittimeout',1,'']]],
  ['with_20xcode_20on_20macos_90',['With Xcode on macOS',['../build_guide.html#build_link_xcode',1,'']]],
  ['without_20contexts_91',['Windows without contexts',['../context_guide.html#context_less',1,'']]],
  ['wl_5fshell_20protocol_92',['Support for the wl_shell protocol',['../news.html#wl_shell_33',1,'']]],
  ['work_20area_93',['work area',['../news.html#workarea_33',1,'Query for the monitor work area'],['../monitor_guide.html#monitor_workarea',1,'Work area']]],
  ['wsi_20extensions_94',['Vulkan WSI extensions',['../compat_guide.html#compat_wsi',1,'']]]
];

==> mingw-w64-clang-aarch64-glfw-3.3.9-2-any.pkg.tar.zst: clangarm64/share/doc/glfw/html/search/all_1a.js <==
var searchData=
[
  ['wait_20for_20events_0',['No window required to wait for events',['../news.html#wait_events_33',1,'']]],
  ['wait_20for_20events_20with_20timeout_1',['Wait for events with timeout',['../news.html#news_32_waittimeout',1,'']]],
  ['wake_20up_2',['Main thread wake-up',['../news.html#news_31_emptyevent',1,'']]],
  ['wayland_20libdecor_20decorations_3',['Wayland libdecor decorations',['../news.html#wayland_libdecor_33',1,'']]],
  ['wayland_20on_20unix_20like_20systems_4',['Dependencies for Wayland on Unix-like systems',['../compile_guide.html#compile_deps_wayland',1,'']]],
  ['wayland_20protocols_20and_20ipc_20standards_5',['Wayland protocols and IPC standards',['../compat_guide.html#compat_wayland',1,'']]],
  ['wayland_20specific_20cmake_20options_6',['Wayland specific CMake options',['../compile_guide.html#compile_options_wayland',1,'']]],
  ['wayland_20specific_20init_20hints_7',['Wayland specific init hints',['../intro_guide.html#init_hints_wayland',1,'']]],
  ['wayland_20support_8',['(Experimental) Wayland support',['../news.html#news_31_wayland',1,'']]],
  ['wayland_20systems_9',['Frambuffer may lack alpha channel on older Wayland systems',['../news.html#wayland_alpha_34',1,'']]],
  ['wgl_20extensions_10',['WGL extensions',['../compat_guide.html#compat_wgl',1,'']]],
  ['wheel_20position_20replaced_20by_20scroll_20offsets_11',['Wheel position replaced by scroll offsets',['../moving_guide.html#moving_wheel',1,'']]],
  ['wide_20hotkeys_12',['Capture of system-wide hotkeys',['../moving_guide.html#moving_syskeys',1,'']]],
  ['width_13',['width',['../struct_g_l_f_wvidmode.html#a698dcb200562051a7249cb6ae154c71d',1,'GLFWvidmode::width'],['../struct_g_l_f_wimage.html#af6a71cc999fe6d3aea31dd7e9687d835',1,'GLFWimage::width']]],
  ['win32_20mbcs_20support_14',['Win32 MBCS support',['../moving_guide.html#moving_mbcs',1,'']]],
  ['window_15',['Creating the window',['../vulkan_guide.html#vulkan_window',1,'']]],
  ['window_20and_20context_16',['Creating a window and context',['../quick_guide.html#quick_create_window',1,'']]],
  ['window_20and_20framebuffer_20sizes_17',['Separation of window and framebuffer sizes',['../moving_guide.html#moving_hidpi',1,'']]],
  ['window_20attention_20request_18',['Window attention request',['../window_guide.html#window_attention',1,'']]],
  ['window_20attribute_19',['Mouse cursor hover window attribute',['../news.html#cursor_hover_33',1,'']]],
  ['window_20attributes_20',['Window attributes',['../news.html#setwindowattrib_33',1,'Support for updating window attributes'],['../window_guide.html#window_attribs',1,'Window attributes']]],
  ['window_20attributes_20and_20cursor_20position_21',['Direct access for window attributes and cursor position',['../news.html#news_31_direct',1,'']]],
  ['window_20close_20flag_22',['Checking the window close flag',['../quick_guide.html#quick_window_close',1,'']]],
  ['window_20closing_20and_20close_20flag_23',['Window closing and close flag',['../window_guide.html#window_close',1,'']]],
  ['window_20closing_20changes_24',['Window closing changes',['../moving_guide.html#moving_window_close',1,'']]],
  ['window_20content_20scale_25',['Window content scale',['../window_guide.html#window_scale',1,'']]],
  ['window_20creation_26',['Window creation',['../window_guide.html#window_creation',1,'']]],
  ['window_20creation_20hints_27',['Window creation hints',['../window_guide.html#window_hints',1,'']]],
  ['window_20damage_20and_20refresh_28',['Window damage and refresh',['../window_guide.html#window_refresh',1,'']]],
  ['window_20destruction_29',['Window destruction',['../window_guide.html#window_destruction',1,'']]],
  ['window_20event_20processing_30',['Window event processing',['../window_guide.html#window_events',1,'']]],
  ['window_20focus_20callback_31',['Window focus callback',['../news.html#news_30_focusfun',1,'']]],
  ['window_20frame_20size_20query_32',['Window frame size query',['../news.html#news_31_framesize',1,'']]],
  ['window_20guide_33',['Window guide',['../window_guide.html',1,'']]],
  ['window_20handle_20parameters_34',['Window handle parameters',['../moving_guide.html#moving_window_handles',1,'']]],
  ['window_20hint_35',['Cursor centering window hint',['../news.html#center_cursor_33',1,'']]],
  ['window_20hint_20and_20attribute_20for_20input_20focus_20on_20show_36',['Window hint and attribute for input focus on show',['../news.html#focusonshow_33',1,'']]],
  ['window_20hints_37',['Window hints',['../window_guide.html#window_hints_osx',1,'macOS specific window hints'],['../moving_guide.html#moving_hints',1,'Persistent window hints'],['../window_guide.html#window_hints_x11',1,'X11 specific window hints']]],
  ['window_20icon_38',['Window icon',['../window_guide.html#window_icon',1,'']]],
  ['window_20icon_20support_39',['Window icon support',['../news.html#news_32_icon',1,'']]],
  ['window_20iconification_40',['Window iconification',['../window_guide.html#window_iconify',1,'']]],
  ['window_20iconification_20callback_41',['Window iconification callback',['../news.html#news_30_iconifyfun',1,'']]],
  ['window_20input_20focus_42',['Window input focus',['../window_guide.html#window_focus',1,'']]],
  ['window_20input_20focus_20control_43',['Window input focus control',['../news.html#news_32_focus',1,'']]],
  ['window_20maximization_44',['Window maximization',['../window_guide.html#window_maximize',1,'']]],
  ['window_20maximization_20callback_45',['Window maximization callback',['../news.html#maximize_33',1,'']]],
  ['window_20maxmimization_20support_46',['Window maxmimization support',['../news.html#news_32_maximize',1,'']]],
  ['window_20mode_20switching_47',['Window mode switching',['../news.html#news_32_setwindowmonitor',1,'']]],
  ['window_20monitor_48',['Window monitor',['../window_guide.html#window_monitor',1,'']]],
  ['window_20objects_49',['Window objects',['../window_guide.html#window_object',1,'']]],
  ['window_20parameter_20to_20clipboard_20functions_50',['Window parameter to clipboard functions',['../news.html#clipboard_window_33',1,'']]],
  ['window_20position_51',['Window position',['../window_guide.html#window_pos',1,'']]],
  ['window_20position_20callback_52',['Window position callback',['../news.html#news_30_wndposfun',1,'']]],
  ['window_20position_20query_53',['Window position query',['../news.html#news_30_wndpos',1,'']]],
  ['window_20properties_20and_20events_54',['Window properties and events',['../window_guide.html#window_properties',1,'']]],
  ['window_20reference_55',['Window reference',['../group__window.html',1,'']]],
  ['window_20related_20attributes_56',['Window related attributes',['../window_guide.html#window_attribs_wnd',1,'']]],
  ['window_20related_20hints_57',['Window related hints',['../window_guide.html#window_hints_wnd',1,'']]],
  ['window_20required_20to_20wait_20for_20events_58',['No window required to wait for events',['../news.html#wait_events_33',1,'']]],
  ['window_20size_59',['Window size',['../window_guide.html#window_size',1,'']]],
  ['window_20size_20limit_20support_60',['Window size limit support',['../news.html#news_32_sizelimits',1,'']]],
  ['window_20size_20limits_61',['Window size limits',['../window_guide.html#window_sizelimits',1,'']]],
  ['window_20support_62',['Multi-window support',['../news.html#news_30_multiwnd',1,'']]],
  ['window_20surface_63',['Creating a Vulkan window surface',['../vulkan_guide.html#vulkan_surface',1,'']]],
  ['window_20title_64',['Window title',['../news.html#news_30_wndtitle',1,'Initial window title'],['../window_guide.html#window_title',1,'Window title']]],
  ['window_20transparency_65',['Window transparency',['../window_guide.html#window_transparency',1,'']]],
  ['window_20user_20pointer_66',['Per-window user pointer',['../news.html#news_30_wndptr',1,'']]],
  ['window_20visibility_67',['Window visibility',['../window_guide.html#window_hide',1,'']]],
  ['window_2edox_68',['window.dox',['../window_8dox.html',1,'']]],
  ['windowed_20full_20screen_20windows_69',['&quot;Windowed full screen&quot; windows',['../window_guide.html#window_windowed_full_screen',1,'']]],
  ['windows_70',['Windows',['../window_guide.html#window_windowed_full_screen',1,'&quot;Windowed full screen&quot; windows'],['../news.html#news_32_noapi',1,'Context-less windows'],['../news.html#news_31_floating',1,'Floating windows'],['../window_guide.html#window_full_screen',1,'Full screen windows'],['../news.html#news_30_hidden',1,'Hidden windows'],['../news.html#news_31_focused',1,'Initially unfocused windows'],['../news.html#news_30_undecorated',1,'Undecorated windows'],['../build_guide.html#build_link_win32',1,'With MinGW or Visual C++ on Windows']]],
  ['windows_20and_20framebuffers_71',['Transparent windows and framebuffers',['../news.html#transparency_33',1,'']]],
  ['windows_20older_20than_20xp_72',['Support for versions of Windows older than XP',['../moving_guide.html#moving_windows',1,'']]],
  ['windows_20specific_20cmake_20options_73',['Windows specific CMake options',['../compile_guide.html#compile_options_win32',1,'']]],
  ['windows_20without_20contexts_74',['Windows without contexts',['../context_guide.html#context_less',1,'']]],
  ['windows_20xinput_20deadzone_20removed_75',['Windows XInput deadzone removed',['../news.html#xinput_deadzone_33',1,'']]],
  ['with_20a_20loader_20library_76',['Loading extension with a loader library',['../context_guide.html#context_glext_auto',1,'']]],
  ['with_20cmake_77',['Generating build files with CMake',['../compile_guide.html#compile_generate',1,'']]],
  ['with_20cmake_20and_20glfw_20source_78',['With CMake and GLFW source',['../build_guide.html#build_link_cmake_source',1,'']]],
  ['with_20cmake_20and_20installed_20glfw_20binaries_79',['With CMake and installed GLFW binaries',['../build_guide.html#build_link_cmake_package',1,'']]],
  ['with_20cmake_20and_20mingw_80',['Cross-compilation with CMake and MinGW',['../compile_guide.html#compile_mingw_cross',1,'']]],
  ['with_20command_20line_20on_20macos_81',['With command-line on macOS',['../build_guide.html#build_link_osx',1,'']]],
  ['with_20makefiles_20and_20pkg_20config_20on_20unix_82',['With makefiles and pkg-config on Unix',['../build_guide.html#build_link_pkgconfig',1,'']]],
  ['with_20mingw_20or_20visual_20c_20on_20windows_83',['With MinGW or Visual C++ on Windows',['../build_guide.html#build_link_win32',1,'']]],
  ['with_20modifiers_20callback_84',['With modifiers callback',['../news.html#charmods_callback_33',1,'Character with modifiers callback'],['../news.html#news_31_charmods',1,'Character with modifiers callback']]],
  ['with_20opengl_85',['Rendering with OpenGL',['../quick_guide.html#quick_render',1,'']]],
  ['with_20the_20cmake_20command_20line_20tool_86',['Generating files with the CMake command-line tool',['../compile_guide.html#compile_generate_cli',1,'']]],
  ['with_20the_20cmake_20gui_87',['Generating files with the CMake GUI',['../compile_guide.html#compile_generate_gui',1,'']]],
  ['with_20the_20right_20libraries_88',['Link with the right libraries',['../build_guide.html#build_link',1,'']]],
  ['with_20timeout_89',['Wait for events with timeout',['../news.html#news_32_waittimeout',1,'']]],
  ['with_20xcode_20on_20macos_90',['With Xcode on macOS',['../build_guide.html#build_link_xcode',1,'']]],
  ['without_20contexts_91',['Windows without contexts',['../context_guide.html#context_less',1,'']]],
  ['wl_5fshell_20protocol_92',['Support for the wl_shell protocol',['../news.html#wl_shell_33',1,'']]],
  ['work_20area_93',['Work area',['../news.html#workarea_33',1,'Query for the monitor work area'],['../monitor_guide.html#monitor_workarea',1,'Work area']]],
  ['wsi_20extensions_94',['Vulkan WSI extensions',['../compat_guide.html#compat_wsi',1,'']]]
];
